@@ -12,23 +12,19 @@
 #    License for the specific language governing permissions and limitations
 #    under the License.
 
-import parser
-import context
-from yaql.functions import builtin, extended
+import functions
+from yaql.language import parser, context
 
-__versioninfo__ = (0, 2, 4)
+__versioninfo__ = (0, 3, 0)
 __version__ = '.'.join(map(str, __versioninfo__))
-__grammar_version__ = '1.0'
 
 
-def parse(expression, write_tables=False):
-    tabmodule = 'yaql_parser_t_v%s' % __grammar_version__
-    return parser.parse(expression, write_tables, tabmodule)
+def parse(expression):
+    return parser.parse(expression)
 
 
-def create_context(include_extended_functions=True):
+def create_context(register_functions=True):
     cont = context.Context()
-    builtin.add_to_context(cont)
-    if include_extended_functions:
-        extended.add_to_context(cont)
+    if register_functions:
+        functions.register(cont)
     return context.Context(cont)
